package server

import (
	"strings"

	"git.pbiernat.dev/egommerce/go-api-pkg/fluentd"
	"github.com/gofiber/fiber/v2"
)

func SetupRoutes(s *Server) {
	api := s.App.Group("/api")
	v1 := api.Group("/v1")
	v1.Post("/checkout", s.CheckoutHandler)

	s.App.Get("/health", s.HealthHandler)
}

func SetupMiddlewares(s *Server) {
	s.App.Use(LoggingMiddleware(s.log))
}

// Middlewares
func LoggingMiddleware(log *fluentd.Logger) func(c *fiber.Ctx) error {
	return func(c *fiber.Ctx) error {
		path := string(c.Request().URI().Path())
		if strings.Contains(path, "/health") {
			return c.Next()
		}

		log.Log("Request: %s, remote: %s, via: %s",
			c.Request().URI().String(),
			c.Context().RemoteIP().String(),
			string(c.Context().UserAgent()))

		return c.Next()
	}
}
